# Microsoft Azure Sphere Image Metadata for Python 

Microsoft Azure Sphere Image Metadata for Python enables users to interact with an Azure Sphere Image.


## Installation

You can find Microsoft Azure Sphere Image Metadata for Python on [PyPi](https://pypi.org/project/azuresphere_imagemetadata/).

1. If you haven't already, [install and/or upgrade the pip](https://pip.pypa.io/en/stable/installing/)
   of your Python environment to a recent version.
2. Run `pip install azuresphere-imagemetadata`.

## Usage

Before using Microsoft Azure Sphere Image Metadata for Python, you must install the Azure Sphere SDK.

- To install the Azure Sphere SDK on Windows, follow the [Windows Quickstart](https://learn.microsoft.com/azure-sphere/install/install-sdk?pivots=cli).
- To install the Azure Sphere SDK on Linux, follow the [Linux Quickstart](https://learn.microsoft.com/azure-sphere/install/install-sdk-linux?pivots=cli-linux).

## Supported host operating systems

- Windows 10 and 11
- Ubuntu 18.04, 20.04, 22.04